//
//  PQServerProtocalView.swift
//  MusicVideoPlus
//
//  Created by SanW on 2021/6/7.
//

import BFFramework
import UIKit

// MARK: - 应用服务协议

/// 应用服务协议
class PQServerProtocalView: UIView {
    public var remindBlock: ((_ sender: UIButton?, _ webUrl: String?) -> Void)?

    public lazy var contentView: UIView = {
        let contentView = UIView()
        contentView.backgroundColor = UIColor.white
        contentView.addCorner(corner: 4)
        return contentView
    }()

    public lazy var titleLab: UILabel = {
        let titleLab = UILabel()
        titleLab.font = UIFont.systemFont(ofSize: 18, weight: .medium)
        titleLab.textAlignment = .center
        titleLab.numberOfLines = 0
        titleLab.textColor = UIColor.black
        return titleLab
    }()

    public lazy var confirmBtn: UIButton = {
        let confirmBtn = UIButton(type: .custom)
        confirmBtn.setTitle("确定", for: .normal)
        confirmBtn.setTitleColor(UIColor.black, for: .normal)
        confirmBtn.tag = 2
        confirmBtn.addTarget(self, action: #selector(btnClck(sender:)), for: .touchUpInside)
        confirmBtn.titleLabel?.font = UIFont.systemFont(ofSize: 16, weight: .medium)
        return confirmBtn
    }()

    lazy var protocolLab: TYAttributedLabel = {
        let protocolLab = TYAttributedLabel()
        protocolLab.highlightedLinkBackgroundColor = UIColor.white
        protocolLab.delegate = self
        protocolLab.numberOfLines = 0
        protocolLab.font = UIFont(name: "PingFang SC", size: 15)
        protocolLab.text = "感谢您选择闪音APP\n我们非常重视您的个人信息安全和隐私保护。依据最新法律要求，使用我们的产品前，请仔细阅读并同意"
        protocolLab.textColor = UIColor.black
        protocolLab.appendLink(withText: "《软件许可及服务协议》", linkFont: UIFont(name: "PingFang SC", size: 15), linkColor: UIColor.hexColor(hexadecimal: "#07C160"), underLineStyle: CTUnderlineStyle(), linkData: cUserProtocol)
        protocolLab.appendLink(withText: "和", linkFont: UIFont(name: "PingFang SC", size: 15), linkColor: UIColor.black, underLineStyle: CTUnderlineStyle(), linkData: nil)
        protocolLab.appendLink(withText: "《隐私政策》", linkFont: UIFont(name: "PingFang SC", size: 15), linkColor: UIColor.hexColor(hexadecimal: "#07C160"), underLineStyle: CTUnderlineStyle(), linkData: cPrivacy)
        protocolLab.appendLink(withText: "，以便我们向您提供更优质的服务！\n\n我们承诺将尽全力保护您的个人信息及合法权益，再次感谢您的信任！", linkFont: UIFont(name: "PingFang SC", size: 15), linkColor: UIColor.black, underLineStyle: CTUnderlineStyle(), linkData: nil)
        return protocolLab
    }()

    override init(frame: CGRect) {
        super.init(frame: frame)
        contentView.addSubview(protocolLab)
        titleLab.text = "服务协议与隐私政策"
        titleLab.textAlignment = .center
        confirmBtn.titleLabel?.font = UIFont.systemFont(ofSize: 18, weight: .semibold)
        confirmBtn.setTitle("同意", for: .normal)
        confirmBtn.setTitleColor(UIColor.white, for: .normal)
        confirmBtn.backgroundColor = UIColor.hexColor(hexadecimal: "#07C160")
        confirmBtn.addCorner(corner: cDefaultMargin * 2.5)
    }

    override func layoutSubviews() {
        super.layoutSubviews()
        addLayout()
    }

    func addLayout() {
        let normalH: CGFloat = cDefaultMargin * 2.5
        var protocolH: CGFloat = protocolLab.getSizeWithWidth(cScreenWidth - cDefaultMargin * 12).height

        if cScreenHeigth <= 568.0 {
            protocolH = protocolH + cDefaultMargin * 4
        }
        let contentH: CGFloat = normalH + cDefaultMargin * 2 + cDefaultMargin + protocolH + cDefaultMargin * 2 + cDefaultMargin * 5 + cDefaultMargin * 2

        contentView.snp.makeConstraints { make in
            make.left.equalTo(self).offset(cDefaultMargin * 4)
            make.right.equalTo(self).offset(-cDefaultMargin * 4)
            make.height.equalTo(contentH)
            make.center.equalTo(self)
        }
        contentView.addCorner(corner: 4)
        titleLab.snp.makeConstraints { make in
            make.left.equalTo(contentView).offset(normalH)
            make.right.equalTo(contentView).offset(-normalH)
            make.height.equalTo(cDefaultMargin * 2)
            make.top.equalTo(contentView).offset(normalH)
        }
        protocolLab.snp.makeConstraints { make in
            make.top.equalTo(titleLab.snp.bottom).offset(cDefaultMargin)
            make.left.right.equalTo(titleLab)
            make.height.equalTo(protocolH)
        }
        confirmBtn.snp.makeConstraints { make in
            make.left.right.equalTo(titleLab)
            make.height.equalTo(cDefaultMargin * 5)
            make.bottom.equalToSuperview().offset(-cDefaultMargin * 2)
        }
    }

    required init?(coder _: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }

    @objc func btnClck(sender: UIButton) {
        removeFromSuperview()
        if remindBlock != nil {
            remindBlock!(sender, nil)
        }
        saveUserDefaults(key: cShowProtocal, value: "1")
    }
}

extension PQServerProtocalView: TYAttributedLabelDelegate {
    func attributedLabel(_: TYAttributedLabel!, textStorageClicked textStorage: TYTextStorageProtocol!, at _: CGPoint) {
        var link: String? = (textStorage as? TYLinkTextStorage)?.linkData as? String ?? ""
        if link == nil || (link?.count ?? 0) <= 0 {
            let range = (textStorage as? TYLinkTextStorage)?.range
            if range?.length == 11 {
                link = cUserProtocol
            } else if range?.length == 6 {
                link = cPrivacy
            }
        }
        if link != nil, (link?.count ?? 0) > 0, remindBlock != nil {
            remindBlock!(nil, link)
        }
    }
}
